AuthError

Enum AuthError 

pub enum AuthError {
    BadRequest(&'static str),
    InternalError(String),
    ValidationFailure(Error),
    VerificationFailure,
    NotPermitted,
}
Error type for different authorization failure scenarios.

Variants



BadRequest(&'static str)

Indicates that something about the request prevented authorization verification from happening properly.



InternalError(String)

Indicates that something about Objectstore prevented authorization verification from happening properly.



ValidationFailure(Error)

Indicates that the provided authorization token is invalid (e.g. expired or malformed).



VerificationFailure

Indicates that an otherwise-valid token was unable to be verified with configured keys.



NotPermitted

Indicates that the requested operation is not authorized and auth enforcement is enabled.

Implementations

Source

impl AuthError

pub fn code(&self) -> &'static str

Return a shortname for the failure reason that can be used to tag metrics.

pub fn log( &self, permission: Option<Permission>, usecase: Option<&str>, enforce: bool, )

Increment a counter and emit a debug log for this auth failure.

If enforce is false, authentication failures will be logged as warnings to ensure they are found and fixed to unblock enabling enforcement.