pub struct AuthAwareService { /* private fields */ }Expand description
Wrapper around [StorageService] that ensures each operation is authorized.
Authorization is performed according to the request’s authorization details, see also
AuthContext. When crate::config::AuthZ::enforce is false, authorization failures are
logged but any unauthorized operations are still allowed to proceed.
Objectstore API endpoints can use AuthAwareService simply by adding it to their handler
function’s argument list like so:
use axum::http::StatusCode;
use objectstore_server::auth::AuthAwareService;
async fn my_endpoint(service: AuthAwareService) -> Result<StatusCode, StatusCode> {
service.delete_object(todo!("pass some ID"))
.await
.map_err(|_| StatusCode::INTERNAL_SERVER_ERROR)?;
Ok(StatusCode::NO_CONTENT)
}Implementations
Sourceimpl AuthAwareService
impl AuthAwareService
Sourcepub fn new(service: StorageService, context: AuthContext, enforce: bool) -> Self
pub fn new(service: StorageService, context: AuthContext, enforce: bool) -> Self
Creates a new AuthAwareService using the given [StorageService], AuthContext,
and enforcement setting.
The context is used to check whether each operation is authorized. enforce controls
whether authorization failures will result in an error response or be ignored.
With an AuthContext::Disabled context, all operations are permitted.
Sourcepub fn check_permission(
&self,
perm: Permission,
context: &ObjectContext,
) -> ApiResult<()>
pub fn check_permission( &self, perm: Permission, context: &ObjectContext, ) -> ApiResult<()>
Checks whether the request is authorized for the given permission on the given context.
Returns Ok(()) if authorized, or an error indicating the reason.
Sourcepub async fn insert_object(
&self,
context: ObjectContext,
key: Option<String>,
metadata: Metadata,
stream: ClientStream,
) -> ApiResult<InsertResponse>
pub async fn insert_object( &self, context: ObjectContext, key: Option<String>, metadata: Metadata, stream: ClientStream, ) -> ApiResult<InsertResponse>
Auth-aware wrapper around [StorageService::insert_object].
Sourcepub async fn get_metadata(&self, id: ObjectId) -> ApiResult<MetadataResponse>
pub async fn get_metadata(&self, id: ObjectId) -> ApiResult<MetadataResponse>
Auth-aware wrapper around [StorageService::get_metadata].
Sourcepub async fn get_object(
&self,
id: ObjectId,
range: Option<ByteRange>,
) -> ApiResult<GetResponse>
pub async fn get_object( &self, id: ObjectId, range: Option<ByteRange>, ) -> ApiResult<GetResponse>
Auth-aware wrapper around [StorageService::get_object].
Sourcepub async fn delete_object(&self, id: ObjectId) -> ApiResult<DeleteResponse>
pub async fn delete_object(&self, id: ObjectId) -> ApiResult<DeleteResponse>
Auth-aware wrapper around [StorageService::delete_object].
Sourcepub async fn initiate_multipart(
&self,
id: ObjectId,
metadata: Metadata,
) -> ApiResult<InitiateMultipartResponse>
pub async fn initiate_multipart( &self, id: ObjectId, metadata: Metadata, ) -> ApiResult<InitiateMultipartResponse>
Auth-aware wrapper around [StorageService::initiate_multipart].
Sourcepub async fn upload_part(
&self,
id: ObjectId,
upload_id: UploadId,
part_number: PartNumber,
content_length: u64,
content_md5: Option<String>,
body: ClientStream,
) -> ApiResult<UploadPartResponse>
pub async fn upload_part( &self, id: ObjectId, upload_id: UploadId, part_number: PartNumber, content_length: u64, content_md5: Option<String>, body: ClientStream, ) -> ApiResult<UploadPartResponse>
Auth-aware wrapper around [StorageService::upload_part].
Sourcepub async fn list_parts(
&self,
id: ObjectId,
upload_id: UploadId,
max_parts: Option<u32>,
part_number_marker: Option<PartNumber>,
) -> ApiResult<ListPartsResponse>
pub async fn list_parts( &self, id: ObjectId, upload_id: UploadId, max_parts: Option<u32>, part_number_marker: Option<PartNumber>, ) -> ApiResult<ListPartsResponse>
Auth-aware wrapper around [StorageService::list_parts].
Sourcepub async fn abort_multipart(
&self,
id: ObjectId,
upload_id: UploadId,
) -> ApiResult<AbortMultipartResponse>
pub async fn abort_multipart( &self, id: ObjectId, upload_id: UploadId, ) -> ApiResult<AbortMultipartResponse>
Auth-aware wrapper around [StorageService::abort_multipart].
Sourcepub async fn complete_multipart(
&self,
id: ObjectId,
upload_id: UploadId,
parts: Vec<CompletedPart>,
) -> ApiResult<CompleteMultipartResponse>
pub async fn complete_multipart( &self, id: ObjectId, upload_id: UploadId, parts: Vec<CompletedPart>, ) -> ApiResult<CompleteMultipartResponse>
Auth-aware wrapper around [StorageService::complete_multipart].