pub struct MeteredBody(pub ClientStream);Expand description
An extractor that converts the request body into a metered ClientStream.
Extracts the ObjectContext from the request path to attribute bandwidth to the correct
per-usecase and per-scope accumulators in addition to the global accumulator.
Tuple Fields
0: ClientStreamTrait Implementations
Sourceimpl Debug for MeteredBody
impl Debug for MeteredBody
Sourceimpl FromRequest<Arc<Services>> for MeteredBody
impl FromRequest<Arc<Services>> for MeteredBody
Sourcetype Rejection = Infallible
type Rejection = Infallible
Sourceasync fn from_request(
request: Request,
state: &ServiceState,
) -> Result<Self, Self::Rejection>
async fn from_request( request: Request, state: &ServiceState, ) -> Result<Self, Self::Rejection>