pub struct DownstreamService(pub Option<String>);Expand description
Extractor for the downstream service identifier from the request header.
This extracts the x-downstream-service header value, which is used to identify which
Kubernetes service or downstream system is making the request. This can be used for
killswitches, rate limiting, and logging.
Tuple Fields
0: Option<String>Implementations